@@ -16,46 +16,49 @@
  */
 package org.apache.jasper.compiler;
 
-import java.util.ArrayList;
 import java.util.Collection;
-import java.util.Deque;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
+import java.util.Vector;
 
-import javax.el.ExpressionFactory;
-import javax.servlet.jsp.tagext.TagLibraryInfo;
+import jakarta.el.ExpressionFactory;
+import jakarta.servlet.jsp.tagext.TagLibraryInfo;
 
 import org.apache.jasper.Constants;
 import org.apache.jasper.JasperException;
+import org.apache.jasper.JspCompilationContext;
 
 /**
  * A repository for various info about the translation unit under compilation.
+ *
+ * @author Kin-man Chung
  */
-public class PageInfo {
 
-    private final List<String> imports;
+class PageInfo {
+
+    private final Vector<String> imports;
     private final Map<String,Long> dependants;
 
     private final BeanRepository beanRepository;
     private final Set<String> varInfoNames;
     private final HashMap<String,TagLibraryInfo> taglibsMap;
-    private final HashMap<String,String> jspPrefixMapper;
-    private final HashMap<String,Deque<String>> xmlPrefixMapper;
-    private final HashMap<String,Mark> nonCustomTagPrefixMap;
+    private final HashMap<String, String> jspPrefixMapper;
+    private final HashMap<String, LinkedList<String>> xmlPrefixMapper;
+    private final HashMap<String, Mark> nonCustomTagPrefixMap;
     private final String jspFile;
     private static final String defaultLanguage = "java";
     private String language;
-    private final String defaultExtends = Constants.JSP_SERVLET_BASE;
+    private final String defaultExtends;
     private String xtends;
     private String contentType = null;
     private String session;
     private boolean isSession = true;
     private String bufferValue;
-    private int buffer = 8 * 1024;
+    private int buffer = 8*1024;
     private String autoFlush;
     private boolean isAutoFlush = true;
     private String isThreadSafeValue;
@@ -74,7 +77,8 @@ public class PageInfo {
     // JSP 2.1
     private String deferredSyntaxAllowedAsLiteralValue;
     private boolean deferredSyntaxAllowedAsLiteral = false;
-    private final ExpressionFactory expressionFactory = ExpressionFactory.newInstance();
+    private final ExpressionFactory expressionFactory =
+        ExpressionFactory.newInstance();
     private String trimDirectiveWhitespacesValue;
     private boolean trimDirectiveWhitespaces = false;
 
@@ -91,16 +95,17 @@ public class PageInfo {
     private boolean hasJspRoot = false;
     private Collection<String> includePrelude;
     private Collection<String> includeCoda;
-    private final List<String> pluginDcls; // Id's for tagplugin declarations
+    private final Vector<String> pluginDcls;  // Id's for tagplugin declarations
 
     // JSP 2.2
     private boolean errorOnUndeclaredNamespace = false;
 
     private final boolean isTagFile;
 
-    PageInfo(BeanRepository beanRepository, String jspFile, boolean isTagFile) {
-        this.isTagFile = isTagFile;
-        this.jspFile = jspFile;
+    PageInfo(BeanRepository beanRepository, JspCompilationContext ctxt) {
+        isTagFile = ctxt.isTagFile();
+        jspFile = ctxt.getJspFile();
+        defaultExtends = ctxt.getOptions().getJspServletBase();
         this.beanRepository = beanRepository;
         this.varInfoNames = new HashSet<>();
         this.taglibsMap = new HashMap<>();
@@ -108,13 +113,13 @@ public class PageInfo {
         this.xmlPrefixMapper = new HashMap<>();
         this.nonCustomTagPrefixMap = new HashMap<>();
         this.dependants = new HashMap<>();
-        this.includePrelude = new ArrayList<>();
-        this.includeCoda = new ArrayList<>();
-        this.pluginDcls = new ArrayList<>();
+        this.includePrelude = new Vector<>();
+        this.includeCoda = new Vector<>();
+        this.pluginDcls = new Vector<>();
         this.prefixes = new HashSet<>();
 
         // Enter standard imports
-        this.imports = new ArrayList<>(Constants.STANDARD_IMPORTS);
+        this.imports = new Vector<>(Constants.STANDARD_IMPORTS);
     }
 
     public boolean isTagFile() {
@@ -122,7 +127,8 @@ public class PageInfo {
     }
 
     /**
-     * Check if the plugin ID has been previously declared. Make a note that this Id is now declared.
+     * Check if the plugin ID has been previously declared.  Make a note
+     * that this Id is now declared.
      *
      * @param id The plugin ID to check
      *
@@ -262,7 +268,8 @@ public class PageInfo {
      *
      * @param prefix The prefix to check
      *
-     * @return true if this translation unit contains the given prefix, false otherwise
+     * @return true if this translation unit contains the given prefix, false
+     * otherwise
      */
     public boolean containsPrefix(String prefix) {
         return prefixes.contains(prefix);
@@ -272,7 +279,6 @@ public class PageInfo {
      * Maps the given URI to the given tag library.
      *
      * @param uri The URI to map
-     *
      * @param info The tag library to be associated with the given URI
      */
     public void addTaglib(String uri, TagLibraryInfo info) {
@@ -302,7 +308,8 @@ public class PageInfo {
      *
      * @param uri The URI to map
      *
-     * @return true if the given URI is mapped to a tag library, false otherwise
+     * @return true if the given URI is mapped to a tag library, false
+     * otherwise
      */
     public boolean hasTaglib(String uri) {
         return taglibsMap.containsKey(uri);
@@ -312,7 +319,6 @@ public class PageInfo {
      * Maps the given prefix to the given URI.
      *
      * @param prefix The prefix to map
-     *
      * @param uri The URI to be associated with the given prefix
      */
     public void addPrefixMapping(String prefix, String uri) {
@@ -320,24 +326,29 @@ public class PageInfo {
     }
 
     /*
-     * Pushes the given URI onto the stack of URIs to which the given prefix is mapped.
+     * Pushes the given URI onto the stack of URIs to which the given prefix
+     * is mapped.
      *
      * @param prefix The prefix whose stack of URIs is to be pushed
-     *
      * @param uri The URI to be pushed onto the stack
      */
     public void pushPrefixMapping(String prefix, String uri) {
-        // Must be LinkedList as it needs to accept nulls
-        xmlPrefixMapper.computeIfAbsent(prefix, k -> new LinkedList<>()).addFirst(uri);
+        LinkedList<String> stack = xmlPrefixMapper.get(prefix);
+        if (stack == null) {
+            stack = new LinkedList<>();
+            xmlPrefixMapper.put(prefix, stack);
+        }
+        stack.addFirst(uri);
     }
 
     /*
-     * Removes the URI at the top of the stack of URIs to which the given prefix is mapped.
+     * Removes the URI at the top of the stack of URIs to which the given
+     * prefix is mapped.
      *
      * @param prefix The prefix whose stack of URIs is to be popped
      */
     public void popPrefixMapping(String prefix) {
-        Deque<String> stack = xmlPrefixMapper.get(prefix);
+        LinkedList<String> stack = xmlPrefixMapper.get(prefix);
         stack.removeFirst();
     }
 
@@ -350,10 +361,10 @@ public class PageInfo {
      */
     public String getURI(String prefix) {
 
-        String uri;
+        String uri = null;
 
-        Deque<String> stack = xmlPrefixMapper.get(prefix);
-        if (stack == null || stack.isEmpty()) {
+        LinkedList<String> stack = xmlPrefixMapper.get(prefix);
+        if (stack == null || stack.size() == 0) {
             uri = jspPrefixMapper.get(prefix);
         } else {
             uri = stack.getFirst();
@@ -368,7 +379,9 @@ public class PageInfo {
     /*
      * language
      */
-    public void setLanguage(String value, Node n, ErrorDispatcher err, boolean pagedir) throws JasperException {
+    public void setLanguage(String value, Node n, ErrorDispatcher err,
+                boolean pagedir)
+        throws JasperException {
 
         if (!"java".equalsIgnoreCase(value)) {
             if (pagedir) {
@@ -395,11 +408,13 @@ public class PageInfo {
     /**
      * Gets the value of the 'extends' page directive attribute.
      *
-     * @param useDefault TRUE if the default (org.apache.jasper.runtime.HttpJspBase) should be returned if this
-     *                       attribute has not been set, FALSE otherwise
+     * @param useDefault TRUE if the default
+     * (org.apache.jasper.runtime.HttpJspBase) should be returned if this
+     * attribute has not been set, FALSE otherwise
      *
-     * @return The value of the 'extends' page directive attribute, or the default
-     *             (org.apache.jasper.runtime.HttpJspBase) if this attribute has not been set and useDefault is TRUE
+     * @return The value of the 'extends' page directive attribute, or the
+     * default (org.apache.jasper.runtime.HttpJspBase) if this attribute has
+     * not been set and useDefault is TRUE
      */
     public String getExtends(boolean useDefault) {
         return (xtends == null && useDefault ? defaultExtends : xtends);
@@ -408,8 +423,9 @@ public class PageInfo {
     /**
      * Gets the value of the 'extends' page directive attribute.
      *
-     * @return The value of the 'extends' page directive attribute, or the default
-     *             (org.apache.jasper.runtime.HttpJspBase) if this attribute has not been set
+     * @return The value of the 'extends' page directive attribute, or the
+     * default (org.apache.jasper.runtime.HttpJspBase) if this attribute has
+     * not been set
      */
     public String getExtends() {
         return getExtends(true);
@@ -431,7 +447,8 @@ public class PageInfo {
     /*
      * buffer
      */
-    public void setBufferValue(String value, Node n, ErrorDispatcher err) throws JasperException {
+    public void setBufferValue(String value, Node n, ErrorDispatcher err)
+        throws JasperException {
 
         if ("none".equalsIgnoreCase(value)) {
             buffer = 0;
@@ -445,7 +462,7 @@ public class PageInfo {
             }
             try {
                 @SuppressWarnings("null") // value can't be null here
-                int k = Integer.parseInt(value.substring(0, value.length() - 2));
+                int k = Integer.parseInt(value.substring(0, value.length()-2));
                 buffer = k * 1024;
             } catch (NumberFormatException e) {
                 if (n == null) {
@@ -471,7 +488,8 @@ public class PageInfo {
     /*
      * session
      */
-    public void setSession(String value, Node n, ErrorDispatcher err) throws JasperException {
+    public void setSession(String value, Node n, ErrorDispatcher err)
+        throws JasperException {
 
         if ("true".equalsIgnoreCase(value)) {
             isSession = true;
@@ -496,7 +514,8 @@ public class PageInfo {
     /*
      * autoFlush
      */
-    public void setAutoFlush(String value, Node n, ErrorDispatcher err) throws JasperException {
+    public void setAutoFlush(String value, Node n, ErrorDispatcher err)
+        throws JasperException {
 
         if ("true".equalsIgnoreCase(value)) {
             isAutoFlush = true;
@@ -521,7 +540,8 @@ public class PageInfo {
     /*
      * isThreadSafe
      */
-    public void setIsThreadSafe(String value, Node n, ErrorDispatcher err) throws JasperException {
+    public void setIsThreadSafe(String value, Node n, ErrorDispatcher err)
+        throws JasperException {
 
         if ("true".equalsIgnoreCase(value)) {
             isThreadSafe = true;
@@ -570,7 +590,8 @@ public class PageInfo {
     /*
      * isErrorPage
      */
-    public void setIsErrorPage(String value, Node n, ErrorDispatcher err) throws JasperException {
+    public void setIsErrorPage(String value, Node n, ErrorDispatcher err)
+        throws JasperException {
 
         if ("true".equalsIgnoreCase(value)) {
             isErrorPage = true;
@@ -595,7 +616,9 @@ public class PageInfo {
     /*
      * isELIgnored
      */
-    public void setIsELIgnored(String value, Node n, ErrorDispatcher err, boolean pagedir) throws JasperException {
+    public void setIsELIgnored(String value, Node n, ErrorDispatcher err,
+                   boolean pagedir)
+        throws JasperException {
 
         if ("true".equalsIgnoreCase(value)) {
             isELIgnored = true;
@@ -615,8 +638,9 @@ public class PageInfo {
     /*
      * deferredSyntaxAllowedAsLiteral
      */
-    public void setDeferredSyntaxAllowedAsLiteral(String value, Node n, ErrorDispatcher err, boolean pagedir)
-            throws JasperException {
+    public void setDeferredSyntaxAllowedAsLiteral(String value, Node n, ErrorDispatcher err,
+                   boolean pagedir)
+        throws JasperException {
 
         if ("true".equalsIgnoreCase(value)) {
             deferredSyntaxAllowedAsLiteral = true;
@@ -636,8 +660,9 @@ public class PageInfo {
     /*
      * trimDirectiveWhitespaces
      */
-    public void setTrimDirectiveWhitespaces(String value, Node n, ErrorDispatcher err, boolean pagedir)
-            throws JasperException {
+    public void setTrimDirectiveWhitespaces(String value, Node n, ErrorDispatcher err,
+                   boolean pagedir)
+        throws JasperException {
 
         if ("true".equalsIgnoreCase(value)) {
             trimDirectiveWhitespaces = true;
@@ -710,7 +735,8 @@ public class PageInfo {
         return errorOnUndeclaredNamespace;
     }
 
-    public void setErrorOnUndeclaredNamespace(boolean errorOnUndeclaredNamespace) {
+    public void setErrorOnUndeclaredNamespace(
+            boolean errorOnUndeclaredNamespace) {
         this.errorOnUndeclaredNamespace = errorOnUndeclaredNamespace;
     }
 }
