@@ -42,10 +42,11 @@ import javax.net.ssl.X509ExtendedKeyManager;
 import javax.net.ssl.X509KeyManager;
 import javax.net.ssl.X509TrustManager;
 import javax.security.auth.x500.X500Principal;
-import javax.servlet.ServletException;
-import javax.servlet.http.HttpServlet;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
+
+import jakarta.servlet.ServletException;
+import jakarta.servlet.http.HttpServlet;
+import jakarta.servlet.http.HttpServletRequest;
+import jakarta.servlet.http.HttpServletResponse;
 
 import org.junit.Assert;
 
@@ -59,7 +60,7 @@ import org.apache.catalina.startup.Tomcat;
 import org.apache.tomcat.jni.Library;
 import org.apache.tomcat.jni.LibraryNotFoundError;
 import org.apache.tomcat.jni.SSL;
-import org.apache.tomcat.util.compat.JreCompat;
+import org.apache.tomcat.util.compat.JrePlatform;
 import org.apache.tomcat.util.descriptor.web.LoginConfig;
 import org.apache.tomcat.util.descriptor.web.SecurityCollection;
 import org.apache.tomcat.util.descriptor.web.SecurityConstraint;
@@ -76,9 +77,7 @@ public final class TesterSupport {
     public static final String LOCALHOST_RSA_JKS = SSL_DIR + "localhost-rsa.jks";
     public static final String LOCALHOST_KEYPASS_JKS = SSL_DIR + "localhost-rsa-copy1.jks";
     public static final String JKS_PASS = "changeit";
-    public static final String JKS_PASS_FILE = SSL_DIR + "keystore-password";
     public static final String JKS_KEY_PASS = "tomcatpass";
-    public static final String JKS_KEY_PASS_FILE = SSL_DIR + "key-password";
     public static final String CA_CERT_PEM = SSL_DIR + CA_ALIAS + "-cert.pem";
     public static final String LOCALHOST_EC_CERT_PEM = SSL_DIR + "localhost-ec-cert.pem";
     public static final String LOCALHOST_EC_KEY_PEM = SSL_DIR + "localhost-ec-key.pem";
@@ -86,6 +85,7 @@ public final class TesterSupport {
     public static final String LOCALHOST_RSA_KEY_PEM = SSL_DIR + "localhost-rsa-key.pem";
     public static final boolean OPENSSL_AVAILABLE;
     public static final int OPENSSL_VERSION;
+    public static final String OPENSSL_ERROR;
     public static final boolean TLSV13_AVAILABLE;
 
     public static final String ROLE = "testrole";
@@ -97,16 +97,18 @@ public final class TesterSupport {
     static {
         boolean available = false;
         int version = 0;
+        String err = "";
         try {
             Library.initialize(null);
             available = true;
             version = SSL.version();
             Library.terminate();
         } catch (Exception | LibraryNotFoundError ex) {
-            // Ignore
+            err = ex.getMessage();
         }
         OPENSSL_AVAILABLE = available;
         OPENSSL_VERSION = version;
+        OPENSSL_ERROR = err;
 
         available = false;
         try {
@@ -130,11 +132,11 @@ public final class TesterSupport {
     }
 
     public static void initSsl(Tomcat tomcat) {
-        initSsl(tomcat, LOCALHOST_RSA_JKS, null, null, null, null);
+        initSsl(tomcat, LOCALHOST_RSA_JKS, null, null);
     }
 
     protected static void initSsl(Tomcat tomcat, String keystore,
-            String keystorePass, String keystorePassFile, String keyPass, String keyPassFile) {
+            String keystorePass, String keyPass) {
 
         Connector connector = tomcat.getConnector();
         connector.setSecure(true);
@@ -158,15 +160,9 @@ public final class TesterSupport {
             sslHostConfig.setSslProtocol("tls");
             certificate.setCertificateKeystoreFile(new File(keystore).getAbsolutePath());
             sslHostConfig.setTruststoreFile(new File(CA_JKS).getAbsolutePath());
-            if (keystorePassFile != null) {
-                certificate.setCertificateKeystorePasswordFile(new File(keystorePassFile).getAbsolutePath());
-            }
             if (keystorePass != null) {
                 certificate.setCertificateKeystorePassword(keystorePass);
             }
-            if (keyPassFile != null) {
-                certificate.setCertificateKeyPasswordFile(new File(keyPassFile).getAbsolutePath());
-            }
             if (keyPass != null) {
                 certificate.setCertificateKeyPassword(keyPass);
             }
@@ -205,12 +201,14 @@ public final class TesterSupport {
         ClientSSLSocketFactory clientSSLSocketFactory = null;
         try {
             SSLContext sc;
-            if (TLSV13_AVAILABLE) {
+            if (TesterSupport.TLSV13_AVAILABLE) {
                  sc = SSLContext.getInstance(Constants.SSL_PROTO_TLSv1_3);
             } else {
                 sc = SSLContext.getInstance(Constants.SSL_PROTO_TLSv1_2);
             }
-            sc.init(getUser1KeyManagers(), getTrustManagers(), null);
+            sc.init(TesterSupport.getUser1KeyManagers(),
+                    TesterSupport.getTrustManagers(),
+                    null);
             clientSSLSocketFactory = new ClientSSLSocketFactory(sc.getSocketFactory());
             javax.net.ssl.HttpsURLConnection.setDefaultSSLSocketFactory(clientSSLSocketFactory);
         } catch (Exception e) {
@@ -228,13 +226,26 @@ public final class TesterSupport {
         return ks;
     }
 
-    protected static boolean isClientRenegotiationSupported(Tomcat tomcat) {
+    public static boolean isRenegotiationSupported(Tomcat tomcat) {
         String protocol = tomcat.getConnector().getProtocolHandlerClassName();
         if (protocol.contains("Apr")) {
             // Disabled by default in 1.1.20 windows binary (2010-07-27)
             return false;
         }
 
+        return true;
+    }
+
+    protected static boolean isClientRenegotiationSupported(Tomcat tomcat) {
+        String protocol = tomcat.getConnector().getProtocolHandlerClassName();
+        if (protocol.contains("Apr")) {
+            // Disabled by default in 1.1.20 windows binary (2010-07-27)
+            return false;
+        }
+        if (protocol.contains("NioProtocol") || (protocol.contains("Nio2Protocol") && JrePlatform.IS_MAC_OS)) {
+            // Doesn't work on all platforms - see BZ 56448.
+            return false;
+        }
         String sslImplementation = System.getProperty("tomcat.test.sslImplementation");
         if (sslImplementation != null && !"${test.sslImplementation}".equals(sslImplementation)) {
             // Assume custom SSL is not supporting this
@@ -245,21 +256,15 @@ public final class TesterSupport {
     }
 
     public static void configureClientCertContext(Tomcat tomcat) {
-        initSsl(tomcat);
+        TesterSupport.initSsl(tomcat);
 
         /* When running on Java 11, TLSv1.3 is enabled by default. The JSSE
          * implementation of TLSv1.3 does not support
          * certificateVerification="optional", a setting on which these tests
-         * depend.
-         * Java 7 does not enable TLSv1.1 or TLS1.2 by default
-         *
-         * Ensure these tests pass with all JREs from Java 7 onwards.
+         * depend. Therefore, force these tests to use TLSv1.2 so that they pass
+         * when running on TLSv1.3.
          */
-        if (JreCompat.isJre8Available()) {
-            tomcat.getConnector().findSslHostConfigs()[0].setProtocols(Constants.SSL_PROTO_TLSv1_2);
-        } else {
-            tomcat.getConnector().findSslHostConfigs()[0].setProtocols(Constants.SSL_PROTO_TLSv1);
-        }
+        tomcat.getConnector().findSslHostConfigs()[0].setProtocols(Constants.SSL_PROTO_TLSv1_2);
 
         // Need a web application with a protected and unprotected URL
         // No file system docBase required
@@ -284,7 +289,7 @@ public final class TesterSupport {
         try {
             KeyStore ks = getKeyStore(CA_JKS);
             X509Certificate cert = (X509Certificate)ks.getCertificate(CA_ALIAS);
-            clientAuthExpectedIssuer = cert.getSubjectX500Principal().toString();
+            clientAuthExpectedIssuer = cert.getSubjectDN().getName();
         } catch (Exception ex) {
             throw new RuntimeException(ex);
         }
@@ -293,7 +298,7 @@ public final class TesterSupport {
         try {
             KeyStore ks = getKeyStore(CLIENT_JKS);
             X509Certificate cert = (X509Certificate)ks.getCertificate(CLIENT_ALIAS);
-            cn = cert.getSubjectX500Principal().toString();
+            cn = cert.getSubjectDN().getName();
         } catch (Exception ex) {
             throw new RuntimeException(ex);
         }
